﻿using AutoFixture;
using Hotline.Api.Controllers;
using Hotline.Application.Tests.Infrastructure;
using Hotline.Identity.Accounts;
using Hotline.Identity.Roles;
using Hotline.Orders;
using Hotline.Settings.Hotspots;
using Hotline.Share.Dtos.File;
using Hotline.Share.Dtos.Order;
using Hotline.Share.Dtos.Users;
using Hotline.Share.Enums.Settings;
using Hotline.Share.Tools;
using Hotline.Users;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.Testing;
using Microsoft.Extensions.DependencyInjection;
using Moq;
using Shouldly;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using XF.Domain.Authentications;
using XF.Domain.Repository;

namespace Hotline.Application.Tests.Controller;
public class OrderControllerTest : TestBase
{
    private readonly OrderController _orderController;
    private readonly IRepository<Hotspot> _hotspotRepository;
    private readonly IOrderRepository _orderRepository;

    public OrderControllerTest(IAccountRepository accountRepository, IRepository<Role> roleRepository, UserController userController, IRepository<Hotspot> hotspotRepository, OrderController orderController, IOrderRepository orderRepository, IServiceScopeFactory scopeFactory, IRepository<User> userRepository) : base(accountRepository, roleRepository, userController, scopeFactory, userRepository)
    {
        _hotspotRepository = hotspotRepository;
        _orderController = orderController;
        _orderController.ControllerContext = new ControllerContext
        {
            HttpContext = new DefaultHttpContext()
        };
        _orderRepository = orderRepository;
    }

    [Fact]
    public async Task GetOrderHandleTimeConfigByAcceptType_Test()
    {
        var result = await _orderController.GetOrderHandleTimeConfigByAcceptType(Share.Enums.FlowEngine.EFlowDirection.OrgToCenter, "10");
        result.Count.ShouldBe(1);
        result.TimeText.ShouldBe("1个工作日");
        result.TimeType.ShouldBe(ETimeType.WorkDay);
    }

    [Fact]
    public async Task CreateOrder_Test()
    {
        await SetPaiDanYuan();
        var orderDto = _fixture.Create<AddOrderDto>();
        var hotspot = await _hotspotRepository.Queryable()
            .OrderByDescending(m => m.CreationTime)
            .FirstAsync();
        orderDto.HotspotId = hotspot.Id;
        orderDto.HotspotName = hotspot.HotSpotName;
        orderDto.HotspotSpliceName = hotspot.HotSpotFullName;
        orderDto.Files = new List<FileDto>();

        var orderResult = await _orderController.Add(orderDto);
        var orderId = orderResult.ToJson().FromJson<OrderDto>().Id;
        var order = await _orderRepository.GetAsync(orderId);
        order.ShouldNotBeNull();
        order.CreatorId.ShouldBe(TestSessionConstants.UserId);
    }
}
